From c3b1bca95450ae40d17c001eee7c0ddae24afcfa Mon Sep 17 00:00:00 2001
From: Zooko O'Whielacronx <zooko@zooko.com>
Date: Mon, 1 Nov 2010 22:33:57 -0700
Subject: [PATCH] tests: make test-with-fake-pkg's unacceptably-old fake
 pycryptopp be 0.5.13 instead of 0.5.17, since 0.5.17 is acceptably new on
 non-x86 archs Also move the fakepkgs directory to be in misc/build_helpers/
 instead of in the base of the source tree.

---
 misc/build_helpers/test-with-fake-pkg.py | 15 ++++++++-------
 1 file changed, 8 insertions(+), 7 deletions(-)

diff --git a/misc/build_helpers/test-with-fake-pkg.py b/misc/build_helpers/test-with-fake-pkg.py
index a663ed49..85395152 100644
--- a/misc/build_helpers/test-with-fake-pkg.py
+++ b/misc/build_helpers/test-with-fake-pkg.py
@@ -1,23 +1,24 @@
 #!/usr/bin/env python
 
 # We put a fake "pycryptopp-0.5.17" package on the PYTHONPATH so that
 # the build system thinks pycryptopp-0.5.17 is already installed. Then
 # we execute run_trial.py. If the build system is too naive/greedy
 # about finding dependencies, it will latch onto the
 # "pycryptopp-0.5.17" and then will be unable to satisfy the
 # requirement (from _auto_deps.py) for pycryptopp >= 0.5.20. This is
 # currently happening on trunk, see #1190. So with trunk, running
 # test-with-fake-pkg.py shows a failure, but with the ticket1190
 # branch, test-with-fake-pkg.py succeeds.
 
 import glob, os, subprocess, sys
 
+fakepkgdir = 'misc/build_helpers/fakepkgs'
 fakepkgname = "pycryptopp"
-fakepkgversion = "0.5.17"
-# testsuite = "allmydata.test.test_cli"
+fakepkgversion = "0.5.13"
 testsuite = "allmydata.test.test_base62"
 
-pkgdirname = os.path.join(os.getcwd(), '%s-%s.egg' % (fakepkgname, fakepkgversion))
+pkgdirname = os.path.join(os.getcwd(), fakepkgdir, '%s-%s.egg' % (fakepkgname, fakepkgversion))
 
 try:
     os.makedirs(pkgdirname)
@@ -1,23 +1,24 @@
 #!/usr/bin/env python
 
-# We put a fake "pycryptopp-0.5.17" package on the PYTHONPATH so that
-# the build system thinks pycryptopp-0.5.17 is already installed. Then
+# We put a fake "pycryptopp-0.5.13" package on the PYTHONPATH so that
+# the build system thinks pycryptopp-0.5.13 is already installed. Then
 # we execute run_trial.py. If the build system is too naive/greedy
 # about finding dependencies, it will latch onto the
@@ -1,23 +1,24 @@
 # we execute run_trial.py. If the build system is too naive/greedy
 # about finding dependencies, it will latch onto the
-# "pycryptopp-0.5.17" and then will be unable to satisfy the
-# requirement (from _auto_deps.py) for pycryptopp >= 0.5.20. This is
+# "pycryptopp-0.5.13" and then will be unable to satisfy the
+# requirement (from _auto_deps.py) for pycryptopp >= 0.5.20 (or
+# pycryptopp >= 0.5.14, depending on machine architecture). This is
 # currently happening on trunk, see #1190. So with trunk, running
 # test-with-fake-pkg.py shows a failure, but with the ticket1190
-- 
2.45.2